
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/mitol/authentication:mitol-django-authentication

from setuptools import setup

setup(**{
    'authors': [
        'MIT Office of Open Learning <mitx-devops@mit.edu>',
    ],
    'classifiers': [
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    'description': 'MIT Open Learning django app extensions for oauth toolkit',
    'install_requires': (
        'django-anymail>=6.0',
        'django<4.0,>=2.2.12',
        'djangorestframework>=3.0.0',
        'djoser==2.1.0',
        'mitol-django-common~=2.6.0',
        'mitol-django-mail~=3.2.1',
        'social-auth-app-django>=3.1.0',
    ),
    'license': 'BSD 3-Clause License',
    'name': 'mitol-django-authentication',
    'namespace_packages': (
        'mitol',
    ),
    'package_data': {
        'mitol.authentication': (
            'CHANGELOG.md',
            'README.md',
            'py.typed',
        ),
    },
    'packages': (
        'mitol',
        'mitol.authentication',
        'mitol.authentication.migrations',
        'mitol.authentication.serializers',
        'mitol.authentication.settings',
        'mitol.authentication.urls',
        'mitol.authentication.views',
    ),
    'version': '1.5.1',
    'zip_safe': True,
})
